==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/installer/messages/ja/base.php <==
<?php
return array (
  '<strong>Admin</strong> Account' => '<strong>管理者</strong> アカウント',
  '<strong>Configuration</strong>' => '<strong>かんたん設定</strong>',
  '<strong>Congratulations</strong>. You\'re done.' => '<strong>おめでとうございます</strong>. 構築が完了しました',
  '<strong>Database</strong> Configuration' => '<strong>データベース</strong> 設定',
  '<strong>Example</strong> contents' => '<strong>サンプル</strong> コンテンツ',
  '<strong>System</strong> Check' => '<strong>必須要件</strong> を確認します',
  '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>ようこそ！</strong> HumHubへ<br>あなたのSNSツールです',
  'Allow access for non-registered users to public content (guest access)' => 'ユーザー登録していない人でも公開コンテンツにアクセスできる（ゲストアクセス）',
  'Allow friendships between members' => 'メンバー間のフレンドシップ機能を有効にする',
  'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'データベースの設定を入力してください。これらの設定が不明な場合はシステム管理者に連絡を取ってください。',
  'Calvin Klein – Between love and madness lies obsession.' => 'カルバンクライン - 愛と狂気の間には執念があります。',
  'Check again' => 'もう一度チェックする',
  'Congratulations! Everything is ok and ready to start over!' => 'おめでとうございます！条件を満たしているのでインストール準備ができました',
  'Create Admin Account' => '管理者アカウントの作成',
  'Downloading & Installing Modules...' => 'モジュールをダウンロードしてインストールしています。',
  'External users can register (show registration form on login)' => 'ユーザー登録を可能にする（ログイン画面に登録画面を表示する）',
  'Here you can decide how new, unregistered users can access HumHub.' => 'HumHubにアクセスした外部ユーザーや、新規ユーザーの閲覧権限を決めてください。',
  'Hostname' => 'ホスト名',
  'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'MySQLのホスト名を入力してください（例えばMySQLが同じマシンで動作していた場合は「localhost」です。）',
  'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHubはモジュールを使うことで自由に機能を追加できます。下記のモジュールはあなたの利用形態に適したモジュールです。<br> <br>モジュールは後から削除・インストールできます。その場合は管理画面を使ってください。',
  'I want to use HumHub for:' => 'あなたがHumHubを利用する形態は',
  'Initializing database...' => 'データベースを構築しています。',
  'My club' => 'クラブ',
  'My community' => '仲間',
  'My company (Social Intranet / Project management)' => '会社（イントラネット、プロジェクト管理）',
  'My educational institution (school, university)' => '教育機関（学校、大学）',
  'Name of Database' => 'データベース名',
  'Name of your network' => 'あなたのネットワークの名前',
  'Newly registered users have to be activated by an admin first' => 'ユーザー登録してもユーザーはアクセスできず、管理者の承認を待つ',
  'Next' => '次',
  'Nike – Just buy it. :wink:' => 'ナイキ – Just buy it. :wink:',
  'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'あなたのSNSには名前が必要です。好きな名前をつけてください。（たとえばあなたの会社名や組織名、クラブ名などです）',
  'Ohh, something went wrong!' => '設定に誤りがあります。',
  'Password' => 'パスワード',
  'Recommended <strong>Modules</strong>' => '推奨 <strong>モジュール</strong>',
  'Registered members can invite new users via email' => 'ログインユーザーは他のユーザーに招待状メールを出せる',
  'Security <strong>Settings</strong>' => '<strong>セキュリティ</strong> 設定',
  'Set up example content (recommended)' => 'サンプルコンテンツを作成する（推奨）',
  'Sign in' => 'サインイン',
  'Skip this step, I want to set up everything manually' => 'かんたん設定をスキップして、後で手動で設定する',
  'Social Network <strong>Name</strong>' => 'SNSの <strong>名前</strong>',
  'The installation completed successfully! Have fun with your new social network.' => 'インストールは正常に完了しました。あなたのSNSをお楽しみください。',
  'The name of the database you want to run HumHub in.' => 'HumHubを構築したいデータベースの名前を入れてください。',
  'This overview shows all system requirements of HumHub.' => '下記はHumHubの全ての必須要件です。',
  'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'このウィザードでHumHubのインストールと初期設定をします。<br><br>続けるには「次」をクリックしてください。',
  'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'HumHubにサンプルコンテンツもインストールしますか？インストールすればHumHubの理解に役立ちます。サンプルコンテンツは後から削除できます。',
  'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'かんたん設定を選ぶと、一般的な設定をあらかじめ選択した状態にします。次のステップでは、選択した設定を実際に有効にするか選べます。',
  'Username' => 'ユーザー名',
  'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => '私たちは有名ブランドのすばらしいスローガンを探しています。 たぶんあなたはいくつかのサンプルを考え出すことができますか？',
  'Welcome Space' => 'スペースにようこそ',
  'Yay! I\'ve just installed HumHub :sunglasses:' => 'HumHubをインストールしたぞ！',
  'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'これで最後です。管理者アカウントを作ってください。このアカウントがSNSを管理します。',
  'Your MySQL password.' => 'MySQLのパスワードを入力してください。',
  'Your MySQL username' => 'MySQLのユーザー名を入力してください。',
  'Your first sample space to discover the platform.' => 'プラットフォームを発見するための最初のサンプルスペース。',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/installer/messages/ja/base.php <==
<?php
return array (
  '<strong>Admin</strong> Account' => '<strong>管理者</strong> アカウント',
  '<strong>Configuration</strong>' => '<strong>かんたん設定</strong>',
  '<strong>Congratulations</strong>. You\'re done.' => '<strong>おめでとうございます</strong>. 構築が完了しました',
  '<strong>Database</strong> Configuration' => '<strong>データベース</strong> 設定',
  '<strong>Example</strong> contents' => '<strong>サンプル</strong> コンテンツ',
  '<strong>System</strong> Check' => '<strong>必須要件</strong> を確認します',
  '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>ようこそ！</strong> HumHubへ<br>あなたのSNSツールです',
  'Allow access for non-registered users to public content (guest access)' => 'ユーザー登録していない人でも公開コンテンツにアクセスできる（ゲストアクセス）',
  'Allow friendships between members' => 'メンバー間のフレンドシップ機能を有効にする',
  'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'データベースの設定を入力してください。これらの設定が不明な場合はシステム管理者に連絡を取ってください。',
  'Calvin Klein – Between love and madness lies obsession.' => 'カルバンクライン - 愛と狂気の間には執念があります。',
  'Check again' => 'もう一度チェックする',
  'Congratulations! Everything is ok and ready to start over!' => 'おめでとうございます！条件を満たしているのでインストール準備ができました',
  'Create Admin Account' => '管理者アカウントの作成',
  'Create the database if it doesn\'t exist yet.' => 'データベースがまだ存在しない場合は作成します。',
  'Downloading & Installing Modules...' => 'モジュールをダウンロードしてインストールしています。',
  'External users can register (show registration form on login)' => 'ユーザー登録を可能にする（ログイン画面に登録画面を表示する）',
  'Here you can decide how new, unregistered users can access HumHub.' => 'HumHubにアクセスした外部ユーザーや、新規ユーザーの閲覧権限を決めてください。',
  'Hostname' => 'ホスト名',
  'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'MySQLのホスト名を入力してください（例えばMySQLが同じマシンで動作していた場合は「localhost」です。）',
  'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHubは非常に柔軟性があり、モジュールが異なるため, さまざまなアプリケーションに合わせて調整および/または拡張できます。 以下のモジュールはほんの一例であり, 選択したアプリケーションにとって最も重要であると私たちが考えたものです。<br><br>モジュールは後でいつでもインストールまたは削除できます。 インストール後, 管理エリアで利用可能なモジュールをさらに見つけることができます。',
  'I want to use HumHub for:' => 'あなたがHumHubを利用する形態は',
  'Initializing database...' => 'データベースを構築しています。',
  'My club' => 'クラブ',
  'My community' => '仲間',
  'My company (Social Intranet / Project management)' => '会社（イントラネット、プロジェクト管理）',
  'My educational institution (school, university)' => '教育機関（学校、大学）',
  'Name of Database' => 'データベース名',
  'Name of your network' => 'あなたのネットワークの名前',
  'Newly registered users have to be activated by an admin first' => 'ユーザー登録してもユーザーはアクセスできず、管理者の承認を待つ',
  'Next' => '次',
  'Nike – Just buy it. :wink:' => 'ナイキ – Just buy it. :wink:',
  'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'あなたのSNSには名前が必要です。好きな名前をつけてください。（たとえばあなたの会社名や組織名、クラブ名などです）',
  'Ohh, something went wrong!' => '設定に誤りがあります。',
  'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => 'オプション: MySQLデータベースサーバーのポート。 デフォルトのポートを使用するには, 空のままにします。',
  'Password' => 'パスワード',
  'Port' => 'ポート',
  'Recommended <strong>Modules</strong>' => '推奨 <strong>モジュール</strong>',
  'Registered members can invite new users via email' => 'ログインユーザーは他のユーザーに招待状メールを出せる',
  'Security <strong>Settings</strong>' => '<strong>セキュリティ</strong> 設定',
  'Set up example content (recommended)' => 'サンプルコンテンツを作成する（推奨）',
  'Sign in' => 'サインイン',
  'Skip this step, I want to set up everything manually' => 'かんたん設定をスキップして、後で手動で設定する',
  'Social Network <strong>Name</strong>' => 'SNSの <strong>名前</strong>',
  'The installation completed successfully! Have fun with your new social network.' => 'インストールは正常に完了しました。あなたのSNSをお楽しみください。',
  'The name of the database you want to run HumHub in.' => 'HumHubを構築したいデータベースの名前を入れてください。',
  'This overview shows all system requirements of HumHub.' => '下記はHumHubの全ての必須要件です。',
  'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'このウィザードでHumHubのインストールと初期設定をします。<br><br>続けるには「次」をクリックしてください。',
  'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'HumHubにサンプルコンテンツもインストールしますか？インストールすればHumHubの理解に役立ちます。サンプルコンテンツは後から削除できます。',
  'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'かんたん設定を選ぶと、一般的な設定をあらかじめ選択した状態にします。次のステップでは、選択した設定を実際に有効にするか選べます。',
  'Username' => 'ユーザー名',
  'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => '私たちは有名ブランドのすばらしいスローガンを探しています。 たぶんあなたはいくつかのサンプルを考え出すことができますか？',
  'Welcome Space' => 'スペースにようこそ',
  'Yay! I\'ve just installed HumHub :sunglasses:' => 'HumHubをインストールしたぞ！',
  'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'これで最後です。管理者アカウントを作ってください。このアカウントがSNSを管理します。',
  'Your MySQL password.' => 'MySQLのパスワードを入力してください。',
  'Your MySQL username' => 'MySQLのユーザー名を入力してください。',
  'Your first sample space to discover the platform.' => 'プラットフォームを発見するための最初のサンプルスペース。',
);
